@@ -26,8 +26,7 @@
 // Konsole
 #include "CharacterColor.h"
 
-namespace Konsole
-{
+namespace Konsole {
 typedef unsigned char LineProperty;
 
 typedef quint16 RenditionFlags;
@@ -58,7 +57,7 @@ const RenditionFlags RE_OVERLINE       = (1 << 10);
  * detailed too be drawn cleanly at normal font scales without anti
  * -aliasing, so those are drawn as regular characters.
  */
-inline bool isSupportedLineChar(quint16 codePoint)
+inline bool isSupportedLineChar(uint codePoint)
 {
     return (codePoint & 0xFF80) == 0x2500 // Unicode block: Mathematical Symbols - Box Drawing
            && !(0x2504 <= codePoint && codePoint <= 0x250B); // Triple and quadruple dash range
@@ -83,7 +82,7 @@ public:
      * @param _real Indicate whether this character really exists, or exists
      *              simply as place holder.
      */
-    explicit inline Character(quint16 _c = ' ',
+    explicit inline Character(uint _c = ' ',
                               CharacterColor  _f = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_FORE_COLOR),
                               CharacterColor  _b = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_BACK_COLOR),
                               RenditionFlags  _r = DEFAULT_RENDITION,
@@ -100,16 +99,16 @@ public:
      * look up the unicode character sequence in the ExtendedCharTable used to
      * create the sequence.
      */
-    quint16 character;
+    uint character;
 
     /** A combination of RENDITION flags which specify options for drawing the character. */
-    RenditionFlags  rendition;
+    RenditionFlags rendition;
 
     /** The foreground color used to draw this character. */
-    CharacterColor  foregroundColor;
+    CharacterColor foregroundColor;
 
     /** The color used to draw this character's background. */
-    CharacterColor  backgroundColor;
+    CharacterColor backgroundColor;
 
     /** Indicate whether this character really exists, or exists simply as place holder.
      *
@@ -125,21 +124,22 @@ public:
     /**
      * returns true if the format (color, rendition flag) of the compared characters is equal
      */
-    bool equalsFormat(const Character& other) const;
+    bool equalsFormat(const Character &other) const;
 
     /**
      * Compares two characters and returns true if they have the same unicode character value,
      * rendition and colors.
      */
-    friend bool operator == (const Character& a, const Character& b);
+    friend bool operator ==(const Character &a, const Character &b);
 
     /**
      * Compares two characters and returns true if they have different unicode character values,
      * renditions or colors.
      */
-    friend bool operator != (const Character& a, const Character& b);
+    friend bool operator !=(const Character &a, const Character &b);
 
-    inline bool isLineChar() const {
+    inline bool isLineChar() const
+    {
         if (rendition & RE_EXTENDED_CHAR) {
             return false;
         } else {
@@ -147,7 +147,8 @@ public:
         }
     }
 
-    inline bool isSpace() const {
+    inline bool isSpace() const
+    {
         if (rendition & RE_EXTENDED_CHAR) {
             return false;
         } else {
@@ -156,25 +157,23 @@ public:
     }
 };
 
-inline bool operator == (const Character& a, const Character& b)
+inline bool operator ==(const Character &a, const Character &b)
 {
     return a.character == b.character && a.equalsFormat(b);
 }
 
-inline bool operator != (const Character& a, const Character& b)
+inline bool operator !=(const Character &a, const Character &b)
 {
     return !operator==(a, b);
 }
 
-inline bool Character::equalsFormat(const Character& other) const
+inline bool Character::equalsFormat(const Character &other) const
 {
-    return backgroundColor == other.backgroundColor &&
-           foregroundColor == other.foregroundColor &&
-           rendition == other.rendition;
+    return backgroundColor == other.backgroundColor
+           && foregroundColor == other.foregroundColor
+           && rendition == other.rendition;
 }
-
 }
 Q_DECLARE_TYPEINFO(Konsole::Character, Q_MOVABLE_TYPE);
 
 #endif // CHARACTER_H
-
