@@ -269,6 +269,24 @@ public:
          * increases/decreases the terminal font size.
          */
         MouseWheelZoomEnabled,
+        /** (bool) Specifies whether emulated up/down key press events are
+         * sent, for mouse scroll wheel events, to programs using the
+         * Alternate Screen buffer; this is mainly for the benefit of
+         * programs that don't natively support mouse scroll events, e.g.
+         * less.
+         *
+         * This also works for scrolling in applications that support Mouse
+         * Tracking events but don't indicate they're interested in those
+         * events; for example, when vim doesn't indicate it's interested
+         * in Mouse Tracking events (i.e. when the mouse is in Normal
+         * (not Visual) mode): http://vimdoc.sourceforge.net/htmldoc/intro.html#Normal
+         * mouse wheel scroll events will send up/down key press events.
+         *
+         * Default value is true.
+         * See also, MODE_Mouse1007 in the Emulation header, which toggles
+         * Alternate Scrolling with escape sequences.
+        */
+        AlternateScrolling,
         /** (int) Keyboard modifiers to show URL hints */
         UrlHintsModifiers
     };
