@@ -37,8 +37,11 @@ using namespace Konsole;
 // FIXME: A dup line from Profile.cpp - redo these
 static const char GENERAL_GROUP[]     = "General";
 
+ProfileWriter::ProfileWriter() = default;
+ProfileWriter::~ProfileWriter() = default;
+
 // All profiles changes are stored under users' local account
-QString KDE4ProfileWriter::getPath(const Profile::Ptr profile)
+QString ProfileWriter::getPath(const Profile::Ptr profile)
 {
     // If any changes are made to this location, check that programs using
     // the Konsole part can write/save profiles
@@ -46,7 +49,7 @@ QString KDE4ProfileWriter::getPath(const Profile::Ptr profile)
 
     return localDataLocation % QLatin1String("/") % profile->untranslatedName() % QLatin1String(".profile");
 }
-void KDE4ProfileWriter::writeProperties(KConfig& config,
+void ProfileWriter::writeProperties(KConfig& config,
                                         const Profile::Ptr profile,
                                         const Profile::PropertyInfo* properties)
 {
@@ -60,15 +63,16 @@ void KDE4ProfileWriter::writeProperties(KConfig& config,
                 groupName = properties->group;
             }
 
-            if (profile->isPropertySet(properties->property))
+            if (profile->isPropertySet(properties->property)) {
                 group.writeEntry(QLatin1String(properties->name),
                                  profile->property<QVariant>(properties->property));
+            }
         }
 
         properties++;
     }
 }
-bool KDE4ProfileWriter::writeProfile(const QString& path , const Profile::Ptr profile)
+bool ProfileWriter::writeProfile(const QString& path , const Profile::Ptr profile)
 {
     KConfig config(path, KConfig::NoGlobals);
 
@@ -80,17 +84,18 @@ bool KDE4ProfileWriter::writeProfile(const QString& path , const Profile::Ptr pr
 
     // Parent profile if set, when loading the profile in future, the parent
     // must be loaded as well if it exists.
-    if (profile->parent())
+    if (profile->parent()) {
         general.writeEntry("Parent", profile->parent()->path());
+    }
 
     if (profile->isPropertySet(Profile::Command)
-            || profile->isPropertySet(Profile::Arguments))
+            || profile->isPropertySet(Profile::Arguments)) {
         general.writeEntry("Command",
                            ShellCommand(profile->command(), profile->arguments()).fullCommand());
+     }
 
     // Write remaining properties
     writeProperties(config, profile, Profile::DefaultPropertyNames);
 
     return true;
 }
-
