@@ -56,6 +56,9 @@
 #include "ZModemDialog.h"
 #include "History.h"
 #include "konsoledebug.h"
+#include "SessionManager.h"
+#include "ProfileManager.h"
+#include "Profile.h"
 
 using namespace Konsole;
 
@@ -66,18 +69,35 @@ static const int ZMODEM_BUFFER_SIZE = 1048576; // 1 Mb
 
 Session::Session(QObject* parent) :
     QObject(parent)
+    , _uniqueIdentifier(QUuid())
     , _shellProcess(nullptr)
     , _emulation(nullptr)
+    , _views(QList<TerminalDisplay *>())
     , _monitorActivity(false)
     , _monitorSilence(false)
     , _notifiedActivity(false)
     , _silenceSeconds(10)
+    , _silenceTimer(nullptr)
+    , _activityTimer(nullptr)
     , _autoClose(true)
     , _closePerUserRequest(false)
+    , _nameTitle(QString())
+    , _displayTitle(QString())
+    , _userTitle(QString())
+    , _localTabTitleFormat(QString())
+    , _remoteTabTitleFormat(QString())
     , _tabTitleSetByUser(false)
+    , _iconName(QString())
+    , _iconText(QString())
     , _addToUtmp(true)
     , _flowControlEnabled(true)
+    , _program(QString())
+    , _arguments(QStringList())
+    , _environment(QStringList())
     , _sessionId(0)
+    , _initialWorkingDir(QString())
+    , _currentWorkingDir(QString())
+    , _reportedWorkingUrl(QUrl())
     , _sessionProcessInfo(nullptr)
     , _foregroundProcessInfo(nullptr)
     , _foregroundPid(0)
@@ -87,6 +107,7 @@ Session::Session(QObject* parent) :
     , _hasDarkBackground(false)
     , _preferredSize(QSize())
     , _readOnly(false)
+    , _isPrimaryScreen(true)
 {
     _uniqueIdentifier = QUuid::createUuid();
 
@@ -98,7 +119,7 @@ Session::Session(QObject* parent) :
     //create emulation backend
     _emulation = new Vt102Emulation();
 
-    connect(_emulation, &Konsole::Emulation::titleChanged, this, &Konsole::Session::setUserTitle);
+    connect(_emulation, &Konsole::Emulation::sessionAttributeChanged, this, &Konsole::Session::setSessionAttribute);
     connect(_emulation, &Konsole::Emulation::stateSet, this, &Konsole::Session::activityStateSet);
     connect(_emulation, &Konsole::Emulation::zmodemDownloadDetected, this, &Konsole::Session::fireZModemDownloadDetected);
     connect(_emulation, &Konsole::Emulation::zmodemUploadDetected, this, &Konsole::Session::fireZModemUploadDetected);
@@ -287,11 +308,13 @@ void Session::addView(TerminalDisplay* widget)
     connect(widget, &Konsole::TerminalDisplay::mouseSignal, _emulation, &Konsole::Emulation::sendMouseEvent);
     connect(widget, &Konsole::TerminalDisplay::sendStringToEmu, _emulation, &Konsole::Emulation::sendString);
 
-    // allow emulation to notify view when the foreground process
-    // indicates whether or not it is interested in mouse signals
-    connect(_emulation, &Konsole::Emulation::programUsesMouseChanged, widget, &Konsole::TerminalDisplay::setUsesMouse);
+    // allow emulation to notify the view when the foreground process
+    // indicates whether or not it is interested in Mouse Tracking events
+    connect(_emulation, &Konsole::Emulation::programRequestsMouseTracking, widget, &Konsole::TerminalDisplay::setUsesMouseTracking);
 
-    widget->setUsesMouse(_emulation->programUsesMouse());
+    widget->setUsesMouseTracking(_emulation->programUsesMouseTracking());
+
+    connect(_emulation, &Konsole::Emulation::enableAlternateScrolling, widget, &Konsole::TerminalDisplay::setAlternateScrolling);
 
     connect(_emulation, &Konsole::Emulation::programBracketedPasteModeChanged, widget, &Konsole::TerminalDisplay::setBracketedPasteMode);
 
@@ -306,6 +329,9 @@ void Session::addView(TerminalDisplay* widget)
 
     connect(widget, &Konsole::TerminalDisplay::focusLost, _emulation, &Konsole::Emulation::focusLost);
     connect(widget, &Konsole::TerminalDisplay::focusGained, _emulation, &Konsole::Emulation::focusGained);
+
+    connect(_emulation, &Konsole::Emulation::setCursorStyleRequest, widget, &Konsole::TerminalDisplay::setCursorStyle);
+    connect(_emulation, &Konsole::Emulation::resetCursorStyleRequest, widget, &Konsole::TerminalDisplay::resetCursorStyle);
 }
 
 void Session::viewDestroyed(QObject* view)
@@ -477,9 +503,10 @@ void Session::run()
     emit started();
 }
 
-void Session::setUserTitle(int what, const QString& caption)
+void Session::setSessionAttribute(int what, const QString& caption)
 {
-    //set to true if anything is actually changed (eg. old _nameTitle != new _nameTitle )
+    // set to true if anything has actually changed
+    // eg. old _nameTitle != new _nameTitle
     bool modified = false;
 
     if ((what == IconNameAndWindowTitle) || (what == WindowTitle)) {
@@ -547,7 +574,7 @@ void Session::setUserTitle(int what, const QString& caption)
     }
 
     if (modified) {
-        emit titleChanged();
+        emit sessionAttributeChanged();
     }
 }
 
@@ -639,8 +666,14 @@ void Session::updateFlowControlState(bool suspended)
 
 void Session::onPrimaryScreenInUse(bool use)
 {
+
+    _isPrimaryScreen = use;
     emit primaryScreenInUse(use);
 }
+bool Session::isPrimaryScreen()
+{
+    return _isPrimaryScreen;
+}
 
 void Session::sessionAttributeRequest(int id)
 {
@@ -906,7 +939,7 @@ void Session::done(int exitCode, QProcess::ExitStatus exitStatus)
 
     if (!_autoClose) {
         _userTitle = i18nc("@info:shell This session is done", "Finished");
-        emit titleChanged();
+        emit sessionAttributeChanged();
         return;
     }
 
@@ -987,7 +1020,7 @@ void Session::setTitle(TitleRole role , const QString& newTitle)
             _displayTitle = newTitle;
         }
 
-        emit titleChanged();
+        emit sessionAttributeChanged();
     }
 }
 
@@ -1138,7 +1171,7 @@ QUrl Session::getUrl()
         bool ok = false;
 
         // check if foreground process is bookmark-able
-        if (isForegroundProcessActive()) {
+        if (isForegroundProcessActive() && _foregroundProcessInfo->isValid()) {
             // for remote connections, save the user and host
             // bright ideas to get the directory at the other end are welcome :)
             if (_foregroundProcessInfo->name(&ok) == QLatin1String("ssh") && ok) {
@@ -1175,7 +1208,7 @@ void Session::setIconName(const QString& iconName)
 {
     if (iconName != _iconName) {
         _iconName = iconName;
-        emit titleChanged();
+        emit sessionAttributeChanged();
     }
 }
 
@@ -1464,10 +1497,10 @@ void Session::setTitle(int role , const QString& title)
 {
     switch (role) {
     case 0:
-        this->setTitle(Session::NameRole, title);
+        setTitle(Session::NameRole, title);
         break;
     case 1:
-        this->setTitle(Session::DisplayedTitleRole, title);
+        setTitle(Session::DisplayedTitleRole, title);
 
         // without these, that title will be overridden by the expansion of
         // title format shortly after, which will confuses users.
@@ -1482,9 +1515,9 @@ QString Session::title(int role) const
 {
     switch (role) {
     case 0:
-        return this->title(Session::NameRole);
+        return title(Session::NameRole);
     case 1:
-        return this->title(Session::DisplayedTitleRole);
+        return title(Session::DisplayedTitleRole);
     default:
         return QString();
     }
@@ -1494,10 +1527,10 @@ void Session::setTabTitleFormat(int context , const QString& format)
 {
     switch (context) {
     case 0:
-        this->setTabTitleFormat(Session::LocalTabTitle, format);
+        setTabTitleFormat(Session::LocalTabTitle, format);
         break;
     case 1:
-        this->setTabTitleFormat(Session::RemoteTabTitle, format);
+        setTabTitleFormat(Session::RemoteTabTitle, format);
         break;
     }
 }
@@ -1506,9 +1539,9 @@ QString Session::tabTitleFormat(int context) const
 {
     switch (context) {
     case 0:
-        return this->tabTitleFormat(Session::LocalTabTitle);
+        return tabTitleFormat(Session::LocalTabTitle);
     case 1:
-        return this->tabTitleFormat(Session::RemoteTabTitle);
+        return tabTitleFormat(Session::RemoteTabTitle);
     default:
         return QString();
     }
@@ -1544,6 +1577,17 @@ int Session::historySize() const
     }
 }
 
+
+void Session::setProfile(const QString &profileName)
+{
+  const QList<Profile::Ptr> profiles = ProfileManager::instance()->allProfiles();
+  foreach (const Profile::Ptr &profile, profiles) {
+    if (profile->name() == profileName) {
+      SessionManager::instance()->setSessionProfile(this, profile);
+    }
+  }
+}
+
 int Session::foregroundProcessId()
 {
     int pid;
