@@ -136,19 +136,6 @@ public:
      * setting) in the terminal display **/
     void setSearchStartToWindowCurrentLine();
 
-    /**
-     * Sets the widget used for searches through the session's output.
-     *
-     * When the user clicks on the "Search Output" menu action the @p searchBar 's
-     * show() method will be called.  The SessionController will then connect to the search
-     * bar's signals to update the search when the widget's controls are pressed.
-     */
-    void setSearchBar(IncrementalSearchBar *searchBar);
-    /**
-     * see setSearchBar()
-     */
-    IncrementalSearchBar *searchBar() const;
-
     /**
      * Sets the action displayed in the session's context menu to hide or
      * show the menu bar.
@@ -269,12 +256,13 @@ private Q_SLOTS:
     void toggleReadOnly();
 
     // other
+    void setupSearchBar();
     void prepareSwitchProfileMenu();
     void updateCodecAction();
     void showDisplayContextMenu(const QPoint &position);
     void movementKeyFromSearchBarReceived(QKeyEvent *event);
     void sessionStateChanged(int state);
-    void sessionTitleChanged();
+    void sessionAttributeChanged();
     void sessionReadOnlyChanged();
     void searchTextChanged(const QString &text);
     void searchCompleted(bool success);
@@ -348,7 +336,6 @@ private:
 
     int _searchStartLine;
     int _prevSearchResultLine;
-    QPointer<IncrementalSearchBar> _searchBar;
 
     KCodecAction *_codecAction;
 
@@ -373,6 +360,7 @@ private:
     QPointer<EditProfileDialog> _editProfileDialog;
 
     QString _searchText;
+    QPointer<IncrementalSearchBar> _searchBar;
 };
 inline bool SessionController::isValid() const
 {
