@@ -73,6 +73,9 @@
 #include "konsole_wcwidth.h"
 #include "konsoleprivate_export.h"
 
+// Qt
+#include <QVector>
+
 struct interval {
     unsigned long first;
     unsigned long last;
@@ -130,12 +133,8 @@ static int bisearch(unsigned long ucs, const struct interval* table, int max)
  * in ISO 10646.
  */
 
-int KONSOLEPRIVATE_EXPORT konsole_wcwidth(quint16 oucs)
+int KONSOLEPRIVATE_EXPORT konsole_wcwidth(uint ucs)
 {
-    /* NOTE: It is not possible to compare quint16 with the new last four lines of characters,
-     * therefore this cast is now necessary.
-     */
-    unsigned long ucs = static_cast<unsigned long>(oucs);
     /* sorted list of non-overlapping intervals of non-spacing characters */
     /* generated by "uniset +cat=Me +cat=Mn +cat=Cf -00AD +1160-11FF +200B c" */
     static const struct interval combining[] = {
@@ -230,8 +229,9 @@ int KONSOLEPRIVATE_EXPORT konsole_wcwidth(quint16 oucs)
 int string_width(const QString& text)
 {
     int w = 0;
-    for (auto i : text) {
-        w += konsole_wcwidth(i.unicode());
+    auto ucs4 = text.toUcs4();
+    for (auto i : ucs4) {
+        w += konsole_wcwidth(i);
     }
     return w;
 }
